@@ -78,18 +78,32 @@ class Sheet:
         )
         return df
 
-    @staticmethod
-    def indirect_cell(left: int = 0, right: int = 0, manual_set: int = 0):
+    def indirect_cell(
+        self,
+        cur_col: str = None,
+        ref_col: str = None,
+        left: int = 0,
+        right: int = 0,
+        manual_set: int = 0,
+    ):
         """
-        Returns a string for setting an indirect cell location to
-        a number `left` or `right`.
+        Returns a string for setting an indirect cell location to a cell.
 
-        `manual_set` can be used to set the indirect cell offset manually.
+        If you want the cell to be relative to column names then set `cur_col`
+        to the column name the formula is going into and `ref_col` to the
+        column name you are wanting to reference.
 
-        Only one direction can be greater than 0.
+        If you know it is simply references a cell that is 3 to the right or
+        left then just give `left` or `right` that value. Only one direction
+        can be greater than 0.
+
+        You can also use `manual_set` to set the indirect cell offset manually
+        using a positive or negative number.
         """
         num = 0
-        if left > 0 and right == 0:
+        if ref_col and cur_col:
+            num = self.col_idx[ref_col] - self.col_idx[cur_col]
+        elif left > 0 and right == 0:
             num -= left
         elif right > 0 and left == 0:
             num += right
@@ -99,19 +113,6 @@ class Sheet:
             raise Exception("Left and Right args can't both be greater then 0.")
         return f'INDIRECT("RC[{num}]",0)'
 
-    def easy_indirect_cell(self, cur_col: str, ref_col: str):
-        """
-        Allows setting up an indirect cell formula.
-
-        Set `cur_col`to the column name of the column the formula is going
-        into.
-
-        Set `ref_col` to the column name of the column you are wanting
-        to reference.
-        """
-        diff = self.col_idx[ref_col] - self.col_idx[cur_col]
-        return self.indirect_cell(manual_set=diff)
-
     def get_column_index(self):
         """
         Creates the column index.
@@ -131,9 +132,9 @@ class Sheet:
         total_rows = len(self.cur_sheet["A"])
         for row in range(1, total_rows):
             column = self.col_idx[col_name]
-            title = self.cur_sheet.cell(row=row + 1, column=column).value
-            if title is not None:
-                row_idx[title] = row + 1
+            cell_value = self.cur_sheet.cell(row=row + 1, column=column).value
+            if cell_value is not None:
+                row_idx[str(cell_value)] = row + 1
         return row_idx
 
     def list_in_string(self, list: list, string: str, lowercase: bool = True):
@@ -156,16 +157,14 @@ class Sheet:
         numbers already.
         """
         row_key, column_key = None, None
+        row_value = str(row_value)
+        column_value = str(column_value)
         # row key setup
-        if type(row_value) == str and row_value in self.row_idx:
+        if row_value in self.row_idx:
             row_key = self.row_idx[row_value]
-        elif type(row_value) == int:
-            row_key = row_value
         # column key setup
-        if type(column_value) == str and column_value in self.col_idx:
+        if column_value in self.col_idx:
             column_key = self.col_idx[column_value]
-        elif type(column_value) == int:
-            column_key = column_value
         return row_key, column_key
 
     def extract_hyperlink(self, cell_value):
@@ -185,17 +184,16 @@ class Sheet:
         else:
             raise ValueError("Cell Value is not an Excel hyperlink")
 
-    def get_cell(self, row_value: str or int, column_value: str or int):
+    def get_cell_by_key(self, row_key: int, column_key: int):
         """
-        Gets the cell value based on the `row_value` and `column_value`.
+        Gets the cell value based on the `row_key` and `column_key`.
+        This is basically the index in excel for columns and rows.
 
         If the cell is a hyperlink that is currently clickable,
         the hyperlink target will be returned.
         """
-        row_k, col_k = self.get_row_col_index(row_value, column_value)
-        # gets the value
-        if row_k is not None and col_k is not None:
-            cell = self.cur_sheet.cell(row=row_k, column=col_k)
+        if row_key is not None and column_key is not None:
+            cell = self.cur_sheet.cell(row=row_key, column=column_key)
             if cell.hyperlink:
                 return cell.hyperlink.target
             if type(cell.value) is str:
@@ -204,10 +202,27 @@ class Sheet:
                     link = self.extract_hyperlink(cell.value)
                     if link:
                         return link
-            return self.cur_sheet.cell(row=row_k, column=col_k).value
+            return self.cur_sheet.cell(row=row_key, column=column_key).value
         else:
             return None
 
+    def get_cell(self, row_value: str or int, column_value: str or int):
+        """
+        Gets the cell value based on the `row_value` and `column_value`.
+
+        If the cell is a hyperlink that is currently clickable,
+        the hyperlink target will be returned.
+        """
+        # sets int to str
+        if type(row_value) is int:
+            row_value = str(row_value)
+        if type(column_value) is int:
+            column_value = str(column_value)
+        # get row and column keys
+        row_key, column_key = self.get_row_col_index(row_value, column_value)
+        # returns the cell value
+        return self.get_cell_by_key(row_key, column_key)
+
     def update_index(self, column_key: str):
         """
         Updates the current row with the `column_key` in the row_idx variable.
@@ -215,24 +230,22 @@ class Sheet:
         # TODO add test for this
         self.row_idx[column_key] = self.cur_sheet._current_row
 
-    def update_cell(
+    def update_cell_by_key(
         self,
-        row_val: str,
-        col_val: str,
+        row_key: int,
+        col_key: int,
         new_val: str or int,
         replace: bool = True,
     ):
         """
-        Updates the cell based on `row_val` and `col_val` to `new_val`.
+        Updates the cell based on `row_key` and `col_key` to `new_val`.
+        This is basically the index in excel for columns and rows.
 
         Returns True if cell was updated and False if it was not updated.
 
         `replace` allows you to determine if a cell will have its
         existing value changed if it is not None.
-
-        Saves after change if `save` is True.
         """
-        row_key, col_key = self.get_row_col_index(row_val, col_val)
         if row_key is not None and col_key is not None:
             cell = self.cur_sheet.cell(row=row_key, column=col_key)
             cur_val = cell.value
@@ -252,6 +265,35 @@ class Sheet:
         else:
             return False
 
+    def update_cell(
+        self,
+        row_val: str,
+        col_val: str,
+        new_val: str or int,
+        replace: bool = True,
+    ):
+        """
+        Updates the cell based on `row_val` and `col_val` to `new_val`.
+
+        Returns True if cell was updated and False if it was not updated.
+
+        `replace` allows you to determine if a cell will have its
+        existing value changed if it is not None.
+        """
+        row_key, col_key = self.get_row_col_index(row_val, col_val)
+        return self.update_cell_by_key(row_key, col_key, new_val, replace)
+
+    def clear_cell(
+        self,
+        row_val: str,
+        col_val: str,
+    ):
+        """
+        Clears the value of the cell based on `row_val` and `col_val`.
+        """
+        row_key, col_key = self.get_row_col_index(row_val, col_val)
+        return self.update_cell_by_key(row_key, col_key, "", True)
+
     def add_new_line(self, cell_dict: dict):
         """
         Adds cell_dict onto a new line within the excel sheet.
@@ -259,10 +301,6 @@ class Sheet:
 
         If dictionary keys match existing columns within the set sheet,
         it will add the value to that column.
-
-        Use `debug` to print info if a column in the `cell_dict` does not exist.
-
-        Saves after change if `save` is True.
         """
         # missing column checker
         for col in cell_dict.keys():
@@ -270,7 +308,7 @@ class Sheet:
             if col not in self.col_idx and col not in self.missing_columns:
                 self.missing_columns.append(col)
                 msg = f"add_new_line: Missing {col} in {self.sheet_name} sheet"
-                self.excel.log(msg, "warning")
+                self.excel.logger.warning(msg)
         column_key = None
         append_list = []
         for col in self.col_idx:
@@ -294,14 +332,13 @@ class Sheet:
     def delete_row(self, col_val: str):
         """
         Deletes row by `column_value`.
-
-        `save` allows you to force a save after deleting a row.
         """
         if col_val not in self.row_idx:
             return None
         row = self.row_idx[col_val]
         self.cur_sheet.delete_rows(row)
         self.row_idx.pop(col_val)  # removes index of row from row_idx
+        self.row_idx = self.get_row_index(self.column_name)
         self.excel.changes_made = True
         return True
 
@@ -313,6 +350,7 @@ class Sheet:
             return None
         column = self.col_idx[column_name]
         self.cur_sheet.delete_cols(column)
+        self.col_idx = self.get_column_index()
         self.excel.changes_made = True
         return True
 
@@ -349,12 +387,13 @@ class Sheet:
         """
         Sets the given `cell` to the given `format` or general by default.
         """
-        if format == "percent":
-            cell.style = "Percent"
-        elif format == "currency":
-            cell.style = "Currency"
-        else:
-            cell.style = "General"
+        match format:
+            case "percent":
+                cell.style = "Percent"
+            case "currency":
+                cell.style = "Currency"
+            case _:
+                cell.style = "General"
 
     def format_picker(self, column: str):
         """
@@ -447,6 +486,17 @@ class Sheet:
                 # color="FF000000",
             )
 
+    def auto_size_columns(self, width_multiplier=1.23, set_height=None):
+        """
+        ph
+        """
+        for col_cells in self.cur_sheet.columns:
+            max_col_len = max(len(str(cell.value)) for cell in col_cells)
+            new_col_lett = openpyxl.utils.get_column_letter(col_cells[0].column)
+            if max_col_len > 0:
+                col_width = max_col_len * width_multiplier
+                self.cur_sheet.column_dimensions[new_col_lett].width = col_width
+
     def format_cell(self, column: str, row_i: int, col_i: int):
         """
         Formats a cell based on the `column` name using `row_i` and `col_i`.
