@@ -83,70 +83,137 @@ class GetIndex(unittest.TestCase):
             "Allison": 5,
             "Daniel": 6,
             "Rob": 7,
+            "123": 8,
         }
         self.assertEqual(row_index, row_index_ans)
 
+    def test_get_row_col_index_with_str(self):
+        row_key, column_key = self.sheet1.get_row_col_index("Brian", "Birth Month")
+        self.assertEqual(row_key, 4)
+        self.assertEqual(column_key, 2)
+
+    def test_get_row_col_index_with_int(self):
+        row_key, column_key = self.sheet1.get_row_col_index(123, "Birth Month")
+        self.assertEqual(row_key, 8)
+        self.assertEqual(column_key, 2)
+
 
 class IndirectCell(unittest.TestCase):
     def setUp(self):
         self.excel_obj = Excel(filename="test\excel_test.xlsx")
         self.sheet1 = Sheet(self.excel_obj, "Name")
 
-    def test_indirect_cell_pos(self):
+    def test_left(self):
         """
         Positive test for indirect_cell func.
         """
         indirect_cell = self.sheet1.indirect_cell(left=7)
         self.assertEqual(indirect_cell, 'INDIRECT("RC[-7]",0)')
 
-    def test_indirect_cell_neg(self):
+    def test_right(self):
         """
         Negative test for indirect_cell func.
         """
         indirect_cell = self.sheet1.indirect_cell(right=5)
         self.assertEqual(indirect_cell, 'INDIRECT("RC[5]",0)')
 
-    def test_indirect_cell_manual(self):
+    def test_manual_set(self):
         """
         Manual setting test for indirect_cell func.
         """
         indirect_cell = self.sheet1.indirect_cell(manual_set=-5)
         self.assertEqual(indirect_cell, 'INDIRECT("RC[-5]",0)')
 
-    def test_indirect_cell_invalid(self):
+    def test_relative_pos(self):
         """
-        invalid args test for indirect_cell func.
+        Positive test for indirect_cell func.
+        """
+        indirect_cell = self.sheet1.indirect_cell(cur_col="Name", ref_col="Age")
+        self.assertEqual(indirect_cell, 'INDIRECT("RC[3]",0)')
+
+    def test_relative_neg(self):
+        """
+        Negative test for indirect_cell func.
+        """
+        indirect_cell = self.sheet1.indirect_cell(cur_col="Age", ref_col="Name")
+        self.assertEqual(indirect_cell, 'INDIRECT("RC[-3]",0)')
+
+    def test_invalid_left_right(self):
+        """
+        invalid left and right args test for indirect_cell func.
         """
         self.assertRaises(Exception, self.sheet1.indirect_cell, right=5, left=5)
 
-    def test_easy_indirect_cell_pos(self):
-        """
-        Positive test for easy_indirect_cell func.
-        """
-        indirect_cell = self.sheet1.easy_indirect_cell("Name", "Age")
-        self.assertEqual(indirect_cell, 'INDIRECT("RC[3]",0)')
 
-    def test_easy_indirect_cell_neg(self):
-        """
-        Negative test for easy_indirect_cell func.
-        """
-        indirect_cell = self.sheet1.easy_indirect_cell("Age", "Name")
-        self.assertEqual(indirect_cell, 'INDIRECT("RC[-3]",0)')
-
-
-class UpdateAndGet(unittest.TestCase):
+class GetCell(unittest.TestCase):
     def setUp(self):
         self.excel_obj = Excel(filename="test\excel_test.xlsx")
         self.sheet1 = Sheet(self.excel_obj, "Name")
-        self.sheet2 = Sheet(self.excel_obj, "Name", "Sheet 2")
-        self.sheet3 = Sheet(self.excel_obj, "Name", "Links")
+
+    def test_get_cell_by_key(self):
+        """
+        ph
+        """
+        self.assertEqual(self.sheet1.get_cell_by_key(2, 3), 1991)
 
     def test_get_cell(self):
         """
         ph
         """
         self.assertEqual(self.sheet1.get_cell("Brian", "Birth Month"), "June")
-        self.assertEqual(self.sheet2.get_cell("Brian", "Birth Month"), "June")
+
+
+class Hyperlink(unittest.TestCase):
+    def setUp(self):
+        self.excel_obj = Excel(filename="test\excel_test.xlsx")
+        self.sheet2 = Sheet(self.excel_obj, "Name", "Links")
+
+    def test_hyperlink_extraction(self):
+        """
+        Tests non activated formula link.
+        """
+        url = "Fantastic4.com"
+        formula_link = f'=HYPERLINK("Fantastic4.com","Website")'
+        extracted_url = self.sheet2.extract_hyperlink(formula_link)
+        self.assertEqual(url, extracted_url)
+
+    def test_get_hyperlink(self):
+        """
+        Tests getting clickable hyperlink.
+        """
+        url = self.sheet2.get_cell("Tony Stark", "Website")
+        self.assertEqual(url, "https://www.Stark.com/")
+
+    def test_get_hyperlink_TypeError(self):
+        """
+        Tests getting clickable hyperlink.
+        """
+        self.assertRaises(TypeError, self.sheet2.extract_hyperlink, None)
+
+    def test_get_hyperlink_ValueError(self):
+        """
+        Tests getting clickable hyperlink.
+        """
+        self.assertRaises(ValueError, self.sheet2.extract_hyperlink, "Wrong")
+
+
+class UpdateCell(unittest.TestCase):
+    def setUp(self):
+        self.excel_obj = Excel(filename="test\excel_test.xlsx")
+        self.sheet1 = Sheet(self.excel_obj, "Name")
+
+    def test_update_cell_by_key(self):
+        """
+        ph
+        """
+        # verify startomg value
+        self.assertEqual(self.sheet1.get_cell_by_key(4, 2), "June")
+        # update value
+        self.assertTrue(self.sheet1.update_cell_by_key(4, 2, "May"))
+        # verify changed value
+        self.assertEqual(self.sheet1.get_cell_by_key(4, 2), "May")
+        # checks for changes made to be True because it has not been saved yet
+        self.assertTrue(self.excel_obj.changes_made)
 
     def test_update_cell(self):
         """
@@ -161,34 +228,6 @@ class UpdateAndGet(unittest.TestCase):
         # checks for changes made to be True because it has not been saved yet
         self.assertTrue(self.excel_obj.changes_made)
 
-    def test_hyperlink_extraction(self):
-        """
-        Tests non activated formula link.
-        """
-        url = "Fantastic4.com"
-        formula_link = f'=HYPERLINK("Fantastic4.com","Website")'
-        extracted_url = self.sheet3.extract_hyperlink(formula_link)
-        self.assertEqual(url, extracted_url)
-
-    def test_get_hyperlink(self):
-        """
-        Tests getting clickable hyperlink.
-        """
-        url = self.sheet3.get_cell("Tony Stark", "Website")
-        self.assertEqual(url, "https://www.Stark.com/")
-
-    def test_get_hyperlink_TypeError(self):
-        """
-        Tests getting clickable hyperlink.
-        """
-        self.assertRaises(TypeError, self.sheet3.extract_hyperlink, None)
-
-    def test_get_hyperlink_ValueError(self):
-        """
-        Tests getting clickable hyperlink.
-        """
-        self.assertRaises(ValueError, self.sheet3.extract_hyperlink, "Wrong")
-
 
 class AddNewLine(unittest.TestCase):
     def setUp(self):
@@ -199,11 +238,13 @@ class AddNewLine(unittest.TestCase):
         """
         ph
         """
+        self.assertEqual(self.sheet1.get_cell("Allison", "Age"), 34)
         cell_dict = {"Name": "Donna", "Birth Month": "October", "Age": 12}
         self.sheet1.add_new_line(cell_dict)
         self.assertEqual(self.sheet1.get_cell("Donna", "Birth Month"), "October")
         self.assertEqual(self.sheet1.get_cell("Donna", "Age"), 12)
         self.assertTrue(self.excel_obj.changes_made)
+        self.assertEqual(self.sheet1.get_cell("Allison", "Age"), 34)
 
     def test_add_new_line_ValueError(self):
         """
@@ -222,17 +263,29 @@ class Delete(unittest.TestCase):
         """
         ph
         """
+        self.assertEqual(self.sheet1.get_cell("Allison", "Birth Month"), "July")
         self.assertEqual(self.sheet1.get_cell("Brian", "Birth Month"), "June")
         self.sheet1.delete_row("Brian")
         self.assertFalse(self.sheet1.get_cell("Brian", "Birth Month"))
+        self.assertEqual(self.sheet1.get_cell("Allison", "Birth Month"), "July")
 
     def test_delete_by_column(self):
         """
         ph
         """
-        self.assertEqual(self.sheet1.get_cell("Brian", "Age"), 33)
-        self.sheet1.delete_column("Age")
-        self.assertFalse(self.sheet1.get_cell("Brian", "Age"))
+        self.assertEqual(self.sheet1.get_cell("Allison", "Age"), 34)
+        self.assertEqual(self.sheet1.get_cell("Brian", "Birth Year"), 1989)
+        self.sheet1.delete_column("Birth Year")
+        self.assertFalse(self.sheet1.get_cell("Brian", "Birth Year"))
+        self.assertEqual(self.sheet1.get_cell("Allison", "Age"), 34)
+
+    def test_clear_cell(self):
+        """
+        ph
+        """
+        self.assertEqual(self.sheet1.get_cell("Brian", "Birth Month"), "June")
+        self.sheet1.clear_cell("Brian", "Birth Month")
+        self.assertEqual(self.sheet1.get_cell("Brian", "Birth Month"), None)
 
 
 class Formatting(unittest.TestCase):
@@ -283,6 +336,20 @@ class Formatting(unittest.TestCase):
         }
         self.sheet1 = Sheet(self.excel_obj, "Name", options=options)
 
+    def test_auto_size_columns(self):
+        """
+        Tests auto_size_columns correctly sizes columns.
+        TODO Verify that test is accurate
+        """
+        # verify current value
+        cur_width = self.sheet1.cur_sheet.column_dimensions["B"].width
+        self.assertEqual(cur_width, 30.7109375)
+        # auto resizes columns
+        self.sheet1.auto_size_columns()
+        # checks for that new size is correct
+        new_width = self.sheet1.cur_sheet.column_dimensions["B"].width
+        self.assertEqual(new_width, 13.53)
+
     def test_format_picker(self):
         """
         ph
